@@ -55,10 +55,10 @@ def test_sim():
             FluxTimeMonitor(size=(1, 1, 0), center=(0, 0, 0), interval=10, name="plane"),
         ],
         symmetry=(0, 1, -1),
-        pml_layers=(
-            PML(num_layers=20),
-            StablePML(num_layers=30),
-            Absorber(num_layers=100),
+        boundary_spec=BoundarySpec(
+            x=Boundary.pml(num_layers=20),
+            y=Boundary.stable_pml(num_layers=30),
+            z=Boundary.absorber(num_layers=100),
         ),
         shutoff=1e-6,
         courant=0.8,
@@ -72,10 +72,10 @@ def test_sim():
     mm = sim.medium_map
     m = sim.get_monitor_by_name("point")
     s = sim.background_structure
-    sim.plot(x=0)
-    sim.plot_eps(x=0)
+    # sim.plot(x=0)
+    # sim.plot_eps(x=0)
     sim.num_pml_layers
-    sim.plot_grid(x=0)
+    # sim.plot_grid(x=0)
     sim.frequency_range
     sim.grid
     sim.num_cells
@@ -205,6 +205,35 @@ def test_monitor_simulation_frequency_range(caplog, fwidth, log_level):
     assert_log_level(caplog, log_level)
 
 
+def test_monitor_downsampling():
+    # test that the downsampling parameters can be set and the colocation validator works
+
+    monitor = FieldMonitor(
+        size=(inf, inf, inf),
+        freqs=np.linspace(0, 200e12, 10001),
+        name="test",
+        interval_space=(1, 1, 1),
+    )
+    assert monitor.colocate is False
+
+    monitor = FieldMonitor(
+        size=(inf, inf, inf),
+        freqs=np.linspace(0, 200e12, 10001),
+        name="test",
+        interval_space=(1, 2, 3),
+    )
+    assert monitor.colocate is True
+
+    monitor = FieldMonitor(
+        size=(inf, inf, inf),
+        freqs=np.linspace(0, 200e12, 10001),
+        name="test",
+        interval_space=(1, 2, 3),
+        colocate=False,
+    )
+    assert monitor.colocate is False
+
+
 @pytest.mark.parametrize("grid_size,log_level", [(0.001, None), (3, 30)])
 def test_large_grid_size(caplog, grid_size, log_level):
     # small fwidth should be inside range, large one should throw warning
@@ -240,7 +269,9 @@ def test_sim_structure_gap(caplog, box_size, log_level):
         size=(10, 10, 10),
         structures=[box],
         sources=[src],
-        pml_layers=[PML(num_layers=5), PML(num_layers=5), PML(num_layers=5)],
+        boundary_spec=BoundarySpec(
+            x=Boundary.pml(num_layers=5), y=Boundary.pml(num_layers=5), z=Boundary.pml(num_layers=5)
+        ),
         run_time=1e-12,
     )
     assert_log_level(caplog, log_level)
@@ -377,6 +408,28 @@ def test_pop_axis():
         assert Ly == _Ly
 
 
+def test_polyslab_merge():
+    """make sure polyslabs from gds get merged when they should."""
+
+    import gdspy
+
+    def make_polyslabs(gap_size):
+        """Construct two rectangular polyslabs separated by a gap."""
+        lib = gdspy.GdsLibrary()
+        cell = lib.new_cell(f"polygons_{gap_size:.2f}")
+        rect1 = gdspy.Rectangle((gap_size / 2, 0), (1, 1))
+        rect2 = gdspy.Rectangle((-1, 0), (-gap_size / 2, 1))
+        cell.add(rect1)
+        cell.add(rect2)
+        return PolySlab.from_gds(gds_cell=cell, gds_layer=0, axis=2, slab_bounds=(-1, 1))
+
+    polyslabs_gap = make_polyslabs(gap_size=0.3)
+    assert len(polyslabs_gap) == 2, "untouching polylsabs were merged incorrectly."
+
+    polyslabs_touching = make_polyslabs(gap_size=0)
+    assert len(polyslabs_touching) == 1, "polyslabs didnt merge correctly."
+
+
 """ medium """
 
 
@@ -693,7 +746,7 @@ def test_source_times():
     g = GaussianPulse(freq0=1, fwidth=0.1)
     ts = np.linspace(0, 30, 1001)
     g.amp_time(ts)
-    g.plot(ts)
+    # g.plot(ts)
 
     # test we can make cw pulse
     from tidy3d.components.source import ContinuousWave
@@ -707,7 +760,7 @@ def test_dipole():
 
     g = GaussianPulse(freq0=1, fwidth=0.1)
     p = PointDipole(center=(1, 2, 3), source_time=g, polarization="Ex")
-    p.plot(y=2)
+    # p.plot(y=2)
 
     with pytest.raises(pydantic.ValidationError) as e_info:
         p = PointDipole(size=(1, 1, 1), source_time=g, center=(1, 2, 3), polarization="Ex")
@@ -719,11 +772,11 @@ def test_FieldSource():
 
     # test we can make planewave
     s = PlaneWave(size=(0, inf, inf), source_time=g, pol_angle=np.pi / 2, direction="+")
-    s.plot(y=0)
+    # s.plot(y=0)
 
     # test we can make gaussian beam
     s = GaussianBeam(size=(0, 1, 1), source_time=g, pol_angle=np.pi / 2, direction="+")
-    s.plot(y=0)
+    # s.plot(y=0)
 
     # test we can make an astigmatic gaussian beam
     s = AstigmaticGaussianBeam(
@@ -737,7 +790,7 @@ def test_FieldSource():
 
     # test we can make mode source
     s = ModeSource(size=(0, 1, 1), direction="+", source_time=g, mode_spec=mode_spec, mode_index=0)
-    s.plot(y=0)
+    # s.plot(y=0)
 
     # test that non-planar geometry crashes plane wave and gaussian beams
     with pytest.raises(ValidationError) as e_info:
@@ -759,7 +812,7 @@ def test_FieldSource():
     from tidy3d.components.source import TFSF
 
     s = TFSF(size=(1, 1, 1), direction="+", source_time=g, injection_axis=2)
-    s.plot(z=0)
+    # s.plot(z=0)
 
 
 """ monitors """
@@ -786,7 +839,7 @@ def test_monitor():
     tmesh = np.linspace(0, 1, 10)
 
     for m in [m1, m2, m3, m4, m5, m6, m7]:
-        m.plot(y=2)
+        # m.plot(y=2)
         m.storage_size(num_cells=100, tmesh=tmesh)
 
     for m in [m2, m4]:
