@@ -3,19 +3,19 @@ from concurrent.futures import ProcessPoolExecutor, process
 
 from rich import pretty, traceback
 
+from .config import config
+
 # version
 from .version import __version__
 
-# pml
-from .components import PML, StablePML, Absorber
-from .components import PMLParams, AbsorberParams
-from .components import DefaultPMLParameters, DefaultStablePMLParameters, DefaultAbsorberParameters
+# updater
+from .updater import Updater
 
 # grid
 from .components import Grid, Coords, GridSpec, UniformGrid, CustomGrid, AutoGrid
 
 # geometry
-from .components import Box, Sphere, Cylinder, PolySlab
+from .components import Box, Sphere, Cylinder, PolySlab, GeometryGroup
 
 # medium
 from .components import Medium, PoleResidue, AnisotropicMedium, PEC, PECMedium
@@ -45,6 +45,12 @@ from .components import DATA_TYPE_MAP, ScalarFieldData, ScalarFieldTimeData
 from .components import ModeData, ModeAmpsData, ModeIndexData, ModeFieldData, PermittivityData
 from .components import ScalarPermittivityData
 
+# boundary
+from .components import BoundarySpec, Boundary, BoundaryEdge, BoundaryEdgeType
+from .components import BlochBoundary, Symmetry, Periodic, PECBoundary, PMCBoundary
+from .components import PML, StablePML, Absorber, PMLParams, AbsorberParams, PMLTypes
+from .components import DefaultPMLParameters, DefaultStablePMLParameters, DefaultAbsorberParameters
+
 # constants imported as `C_0 = td.C_0` or `td.constants.C_0`
 from .constants import C_0, ETA_0, HBAR, EPSILON_0, MU_0, Q_e, inf
 
@@ -55,9 +61,6 @@ from . import plugins
 # get material `mat` and variant `var` as `material_library[mat][var]`
 from .material_library import material_library
 
-# logging
-from .log import log, set_logging_level, set_logging_file
-
 # for docs
 from .components.medium import AbstractMedium
 from .components.geometry import Geometry
@@ -65,6 +68,18 @@ from .components.source import Source, SourceTime
 from .components.monitor import Monitor
 from .components.grid import YeeGrid, FieldGrid, Coords1D
 
+# logging
+from .log import log, set_logging_file
+
+
+def set_logging_level(level: str) -> None:
+    """Raise a warning here instead of setting the logging level."""
+    raise DeprecationWarning(
+        "``set_logging_level`` no longer supported. "
+        f"To set the logging level, call ``tidy3d.config.logging_level = {level}``."
+    )
+
+
 # make all stdout and errors pretty
 pretty.install()
 # traceback.install()
