@@ -10,14 +10,17 @@ import numpy as np
 import h5py
 import pydantic as pd
 
-from .types import Numpy, Direction, Array, numpy_encoding, Literal, Ax, Coordinate, Symmetry, Axis
+from .types import Numpy, Direction, Array, numpy_encoding, Literal, Ax, Coordinate, Axis
+from .types import ArrayLike
 from .base import Tidy3dBaseModel, TYPE_TAG_STR
 from .simulation import Simulation
+from .boundary import Symmetry, BlochBoundary
 from .monitor import Monitor
 from .grid import Grid, Coords
 from .viz import add_ax_if_none, equal_aspect
 from ..log import DataError, log
 from ..constants import HERTZ, SECOND, MICROMETER
+from ..updater import Updater
 
 
 # mapping of data coordinates to units for assigning .attrs to the xarray objects
@@ -49,7 +52,37 @@ class Tidy3dDataArray(xr.DataArray):
 """ Base data classes """
 
 
-class Tidy3dData(Tidy3dBaseModel):
+class Tidy3dBaseDataModel(Tidy3dBaseModel):
+    """Tidy3dBaseModel, but with yaml and json IO methods disabled."""
+
+    def _json_string(self, include_unset: bool = True) -> str:
+        """Disable exporting to json string."""
+        raise DataError("Can't export json string of Tidy3dData.")
+
+    def to_json(self, fname: str) -> None:
+        """Disable exporting to json file."""
+        raise DataError("Can't export json file of Tidy3dData, use `.to_file(fname.hdf5)` instead.")
+
+    def to_yaml(self, fname: str) -> None:
+        """Disable exporting to yaml file."""
+        raise DataError("Can't export yaml file of Tidy3dData, use `.to_file(fname.hdf5)` instead.")
+
+    @classmethod
+    def from_json(cls, fname: str, **parse_file_kwargs):
+        """Disable loading from json file."""
+        raise DataError(
+            "Can't load Tidy3dData from .json file, use `.from_file(fname.hdf5)` instead."
+        )
+
+    @classmethod
+    def from_yaml(cls, fname: str, **parse_raw_kwargs):
+        """Disable loading from yaml file."""
+        raise DataError(
+            "Can't load Tidy3dData from .yaml file, use `.from_file(fname.hdf5)` instead."
+        )
+
+
+class Tidy3dData(Tidy3dBaseDataModel):
     """Base class for data associated with a simulation."""
 
     class Config:  # pylint: disable=too-few-public-methods
@@ -330,7 +363,7 @@ class SpatialCollectionData(CollectionData, ABC):
     symmetry: Tuple[Symmetry, Symmetry, Symmetry] = pd.Field(
         (0, 0, 0),
         title="Symmetry Eigenvalues",
-        description="igenvalues of the symmetry under reflection in x, y, and z.",
+        description="Eigenvalues of the symmetry under reflection in x, y, and z.",
     )
 
     symmetry_center: Coordinate = pd.Field(
@@ -402,7 +435,9 @@ class SpatialCollectionData(CollectionData, ABC):
                     centered_data_array = centered_data_array.isel(**{coord_name: 0})
                 else:
                     interp_dict[coord_name] = coord_val_map[coord_name]
-            centered_data_dict[field_name] = centered_data_array.interp(**interp_dict)
+            centered_data_dict[field_name] = centered_data_array.interp(
+                **interp_dict, kwargs={"bounds_error": True}
+            )
         return xr.Dataset(centered_data_dict)
 
     @property
@@ -647,7 +682,7 @@ class ScalarFieldTimeData(ScalarSpatialData, TimeData):
     >>> data = ScalarFieldTimeData(values=values, x=x, y=y, z=z, t=t)
     """
 
-    values: Array[float] = pd.Field(
+    values: ArrayLike = pd.Field(
         ...,
         title="Scalar Field Values",
         description="Multi-dimensional array storing the raw scalar field values in time domain.",
@@ -1033,7 +1068,7 @@ DATA_TYPE_MAP = {
 }
 
 
-class AbstractSimulationData(Tidy3dBaseModel, ABC):
+class AbstractSimulationData(Tidy3dBaseDataModel, ABC):
     """Abstract class to store a simulation and some data associated with it."""
 
     simulation: Simulation = pd.Field(
@@ -1418,7 +1453,7 @@ class SimulationData(AbstractSimulationData):
         if normalize_index is None:
             return sim_data_norm
 
-        # if data alreadty normalized
+        # if data already normalized
         if self.normalized:
 
             # if with a different normalize index, raise an error
@@ -1451,11 +1486,14 @@ class SimulationData(AbstractSimulationData):
 
         times = self.simulation.tmesh
         dt = self.simulation.dt
+        boundaries = self.simulation.boundary_spec.to_list
+        boundaries = [item for boundary in boundaries for item in boundary]
+        complex_fields = any(isinstance(item, BlochBoundary) for item in boundaries)
 
         def normalize_data(monitor_data):
             """normalize a monitor data instance using the source time parameters."""
             freqs = monitor_data.f
-            source_freq_amps = source_time.spectrum(times, freqs, dt)
+            source_freq_amps = source_time.spectrum(times, freqs, dt, complex_fields)
             # We remove the user-defined phase from the normalization. Otherwise, with a single
             # source, we would get the exact same fields regardless of the source_time phase.
             # Instead we would like the field phase to be determined by the source_time phase.
@@ -1528,8 +1566,10 @@ class SimulationData(AbstractSimulationData):
         with h5py.File(fname, "r") as f_handle:
 
             # construct the original simulation from the json string
-            sim_json = Tidy3dData.load_string(f_handle, "sim_json")
-            simulation = Simulation.parse_raw(sim_json)
+            sim_json_str = Tidy3dData.load_string(f_handle, "sim_json")
+            updater = Updater.from_string(sim_json_str)
+            sim_dict = updater.update_to_current()
+            simulation = Simulation.parse_obj(sim_dict)
 
             # get the log if exists
             log_string = Tidy3dData.load_string(f_handle, "log_string")
