@@ -4,14 +4,14 @@
 from abc import ABC, abstractmethod
 from typing import List, Tuple, Union, Any, Callable
 from math import isclose
+import functools
 
 import pydantic
 import numpy as np
-from gdspy import boolean
 from shapely.geometry import Point, Polygon, box, MultiPolygon
 from descartes import PolygonPatch
 
-from .base import Tidy3dBaseModel
+from .base import Tidy3dBaseModel, cache
 from .types import Bound, Size, Coordinate, Axis, Coordinate2D, tidynumpy, Array
 from .types import Vertices, Ax, Shapely
 from .viz import add_ax_if_none, equal_aspect
@@ -622,7 +622,7 @@ class Planar(Geometry, ABC):
         """
 
     @property
-    def bounds(self):
+    def bounds(self) -> Bound:
         """Returns bounding box for planar geometry, may implement for subclasses.
 
         Returns
@@ -842,6 +842,7 @@ class Box(Geometry):
         length_factor: float = ARROW_LENGTH_FACTOR,
         width_factor: float = ARROW_WIDTH_FACTOR,
         both_dirs: bool = False,
+        sim_bounds: Bound = None,
         ax: Ax = None,
     ) -> Ax:
         """Adds an arrow to the axis if with options if certain conditions met.
@@ -874,18 +875,23 @@ class Box(Geometry):
         """
 
         plot_axis, _ = self.parse_xyz_kwargs(x=x, y=y, z=z)
-        arrow_axis = [component == 0 for component in direction]
-        arrow_length, arrow_width = self._arrow_dims(ax, length_factor, width_factor)
+
+        arrow_length, arrow_width = self._arrow_dims(
+            ax=ax,
+            length_factor=length_factor,
+            width_factor=width_factor,
+            sim_bounds=sim_bounds,
+            plot_axis=plot_axis,
+        )
 
         # conditions to check to determine whether to plot arrow
         arrow_intersecting_plane = len(self.intersections(x=x, y=y, z=z)) > 0
-        arrow_perp_to_screen = arrow_axis.index(0.0) != plot_axis
-        arrow_not_cartesian_axis = arrow_axis.count(0.0) > 1
+        _, (dx, dy) = self.pop_axis(direction, axis=plot_axis)
+        components_in_plane = any(not np.isclose(component, 0) for component in (dx, dy))
 
         # plot if arrow in plotting plane and some non-zero component can be displayed.
-        if arrow_intersecting_plane and (arrow_not_cartesian_axis or arrow_perp_to_screen):
+        if arrow_intersecting_plane and components_in_plane:
             _, (x0, y0) = self.pop_axis(self.center, axis=plot_axis)
-            _, (dx, dy) = self.pop_axis(direction, axis=plot_axis)
 
             def add_arrow(sign=1.0):
                 """Add an arrow to the axes and include a sign to direction."""
@@ -906,26 +912,37 @@ class Box(Geometry):
 
         return ax
 
-    def _arrow_dims(
+    def _arrow_dims(  # pylint: disable=too-many-locals
         self,
         ax: Ax,
         length_factor: float = ARROW_LENGTH_FACTOR,
         width_factor: float = ARROW_WIDTH_FACTOR,
+        sim_bounds: Bound = None,
+        plot_axis: Axis = None,
     ) -> Tuple[float, float]:
         """Length and width of arrow based on axes size and length and width factors."""
 
-        # get the sizes of the matplotlib axes
-        xmin, xmax = ax.get_xlim()
-        ymin, ymax = ax.get_ylim()
-        ax_width = xmax - xmin
-        ax_height = ymax - ymin
+        if sim_bounds is not None:
+
+            # use the sim_bounds to get sizes
+            rmin, rmax = sim_bounds
+            _, (xmin, ymin) = self.pop_axis(rmin, axis=plot_axis)
+            _, (xmax, ymax) = self.pop_axis(rmax, axis=plot_axis)
+
+        else:
+            # get the sizes of the matplotlib axes
+            xmin, xmax = ax.get_xlim()
+            ymin, ymax = ax.get_ylim()
+
+        width = xmax - xmin
+        height = ymax - ymin
 
         # apply length factor to the minimum size to get arrow length
-        arrow_length = length_factor * min(ax_width, ax_height)
+        arrow_length = length_factor * min(width, height)
 
         # constrain arrow width by the maximum size and the max arrow width factor
         arrow_width = width_factor * arrow_length
-        arrow_width = min(arrow_width, MAX_ARROW_WIDTH_FACTOR * max(ax_width, ax_height))
+        arrow_width = min(arrow_width, MAX_ARROW_WIDTH_FACTOR * max(width, height))
 
         return arrow_length, arrow_width
 
@@ -988,7 +1005,7 @@ class Sphere(Circular):
         return [Point(x0, y0).buffer(0.5 * intersect_dist)]
 
     @property
-    def bounds(self):
+    def bounds(self) -> Bound:
         """Returns bounding box min and max coordinates.
 
         Returns
@@ -1092,7 +1109,7 @@ class Cylinder(Circular, Planar):
         return inside_radius * inside_height
 
     @property
-    def bounds(self):
+    def bounds(self) -> Bound:
         """Returns bounding box min and max coordinates.
 
         Returns
@@ -1371,7 +1388,13 @@ class PolySlab(Planar):
         # apply scaling and convert vertices into polyslabs
         all_vertices = [vertices * gds_scale for vertices in all_vertices]
         all_vertices = [vertices.tolist() for vertices in all_vertices]
-        poly_set = boolean(all_vertices, None, "or")
+        polygons = (Polygon(vertices) for vertices in all_vertices)
+        polys_union = functools.reduce(lambda poly1, poly2: poly1.union(poly2), polygons)
+
+        if isinstance(polys_union, Polygon):
+            all_vertices = [cls.strip_coords(polys_union)[0]]
+        elif isinstance(polys_union, MultiPolygon):
+            all_vertices = [cls.strip_coords(polygon)[0] for polygon in polys_union.geoms]
 
         return [
             cls(
@@ -1382,7 +1405,7 @@ class PolySlab(Planar):
                 sidewall_angle=sidewall_angle,
                 **kwargs,
             )
-            for verts in poly_set.polygons
+            for verts in all_vertices
         ]
 
     @property
@@ -2081,3 +2104,82 @@ class PolySlab(Planar):
 # geometries that can be used to define structures.
 GeometryFields = (Box, Sphere, Cylinder, PolySlab)
 GeometryType = Union[GeometryFields]
+
+
+class GeometryGroup(Geometry):
+    """A collection of Geometry objects that can be called as a single geometry object."""
+
+    geometries: List[GeometryType] = pydantic.Field(
+        [],
+        title="Geometries",
+        description="List of geometries in a single grouping. "
+        "Can provide significant performance enhancement in ``Structure`` when all geometries are "
+        "assigned the same medium.",
+        min_items=1,
+    )
+
+    @property
+    @cache
+    def bounds(self) -> Bound:
+        """Returns bounding box min and max coordinates.
+
+        Returns
+        -------
+        Tuple[float, float, float], Tuple[float, float, float]
+            Min and max bounds packaged as ``(minx, miny, minz), (maxx, maxy, maxz)``.
+        """
+
+        bounds = tuple(geometry.bounds for geometry in self.geometries)
+        rmins = (bound[0] for bound in bounds)
+        rmaxs = (bound[1] for bound in bounds)
+
+        rmin = functools.reduce(min, rmins)
+        rmax = functools.reduce(max, rmaxs)
+
+        return rmin, rmax
+
+    def intersections(self, x: float = None, y: float = None, z: float = None) -> List[Shapely]:
+        """Returns list of shapely geoemtries at plane specified by one non-None value of x,y,z.
+
+        Parameters
+        ----------
+        x : float = None
+            Position of plane in x direction, only one of x,y,z can be specified to define plane.
+        y : float = None
+            Position of plane in y direction, only one of x,y,z can be specified to define plane.
+        z : float = None
+            Position of plane in z direction, only one of x,y,z can be specified to define plane.
+
+        Returns
+        -------
+        List[shapely.geometry.base.BaseGeometry]
+            List of 2D shapes that intersect plane.
+            For more details refer to
+            `Shapely's Documentaton <https://shapely.readthedocs.io/en/stable/project.html>`_.
+        """
+
+        all_intersections = (geometry.intersections(x=x, y=y, z=z) for geometry in self.geometries)
+
+        return functools.reduce(lambda a, b: a + b, all_intersections)
+
+    def inside(self, x, y, z) -> bool:
+        """Returns ``True`` if point ``(x,y,z)`` is inside volume of :class:`GeometryGroup`.
+
+        Parameters
+        ----------
+        x : float
+            Position of point in x direction.
+        y : float
+            Position of point in y direction.
+        z : float
+            Position of point in z direction.
+
+        Returns
+        -------
+        bool
+            True if point ``(x,y,z)`` is inside geometry.
+        """
+
+        individual_insides = (geometry.inside(x, y, z) for geometry in self.geometries)
+
+        return functools.reduce(lambda a, b: a | b, individual_insides)
