@@ -9,7 +9,8 @@ import pydantic as pd
 from .grid import Coords1D, Coords, Grid
 from .mesher import GradedMesher, MesherType
 from ..base import Tidy3dBaseModel
-from ..types import Axis, Symmetry
+from ..types import Axis
+from ..boundary import Symmetry
 from ..source import SourceType
 from ..structure import Structure
 from ..geometry import Box
@@ -322,13 +323,12 @@ class AutoGrid(GridSpec1d):
             if sym != 0:
                 sim_cent[dim] += sim_size[dim] / 4
                 sim_size[dim] /= 2
+        symmetry_domain = Box(center=sim_cent, size=sim_size)
 
-        struct_list = [
-            Structure(geometry=Box(center=sim_cent, size=sim_size), medium=structures[0].medium)
-        ]
-        # Remove structures that are outside the simulation domain (with symmetry applied)
+        # New list of structures with symmetry applied
+        struct_list = [Structure(geometry=symmetry_domain, medium=structures[0].medium)]
         for structure in structures[1:]:
-            if struct_list[0].geometry.intersects(structure.geometry):
+            if symmetry_domain.intersects(structure.geometry):
                 struct_list.append(structure)
 
         # parse structures
@@ -351,6 +351,18 @@ class AutoGrid(GridSpec1d):
         # generate boundaries
         bound_coords = np.append(0.0, np.cumsum(np.concatenate(dl_list)))
         bound_coords += interval_coords[0]
+
+        # fix simulation domain boundaries which may be slightly off
+        domain_bounds = [bound[axis] for bound in symmetry_domain.bounds]
+        if not np.all(np.isclose(bound_coords[[0, -1]], domain_bounds)):
+            raise SetupError(
+                f"AutoGrid coordinates along axis {axis} do not match the simulation "
+                "domain, indicating an unexpected error in the meshing. Please create a github "
+                "issue so that the problem can be investigated. In the meantime, switch to "
+                f"uniform or custom grid along {axis}."
+            )
+        bound_coords[[0, -1]] = domain_bounds
+
         return np.array(bound_coords)
 
 
