@@ -5,7 +5,7 @@ from typing import List, Union, Tuple
 import pydantic
 import numpy as np
 
-from .types import Literal, Ax, EMField, ArrayLike, Array
+from .types import Literal, Ax, EMField, ArrayLike, Array, Bound
 from .geometry import Box
 from .validators import assert_plane
 from .mode import ModeSpec
@@ -158,6 +158,44 @@ class AbstractFieldMonitor(Monitor, ABC):
         description="Collection of field components to store in the monitor.",
     )
 
+    interval_space: Tuple[
+        pydantic.PositiveInt, pydantic.PositiveInt, pydantic.PositiveInt
+    ] = pydantic.Field(
+        (1, 1, 1),
+        title="Spatial interval",
+        description="Number of grid step intervals between monitor recordings. If equal to 1, "
+        "there will be no downsampling. If greater than 1, fields will be downsampled "
+        "and automatically colocated.",
+    )
+
+    colocate: bool = pydantic.Field(
+        None,
+        title="Colocate fields",
+        description="Toggle whether fields should be colocated to grid cell centers. Default: "
+        "``False`` if ``interval_space`` is 1 in each direction, ``True`` if ``interval_space`` "
+        "is greater than one in any direction.",
+    )
+
+    @pydantic.validator("colocate", always=True)
+    def set_default_colocate(cls, val, values):
+        """Toggle default field colocation setting based on `interval_space`."""
+        interval_space = values.get("interval_space")
+        if val is None:
+            val = not sum(interval_space) == 3
+        return val
+
+    def downsampled_num_cells(self, num_cells: Tuple[int, int, int]) -> Tuple[int, int, int]:
+        """Given a tuple of the number of cells spanned by the monitor along each dimension,
+        return the number of cells one would have after downsampling based on ``interval_space``.
+        """
+        num_cells_new = list(num_cells.copy())
+        for idx, interval in enumerate(self.interval_space):
+            if interval == 1 or num_cells[idx] < 4 or (num_cells[idx] - 1) <= interval:
+                continue
+            num_cells_new[idx] = np.floor((num_cells[idx] - 1) / interval) + 1
+            num_cells_new[idx] += int((num_cells[idx] - 1) % interval > 0)
+        return num_cells_new
+
 
 class PlanarMonitor(Monitor, ABC):
     """:class:`Monitor` that has a planar geometry."""
@@ -178,14 +216,20 @@ class AbstractModeMonitor(PlanarMonitor, FreqMonitor):
         description="Parameters to feed to mode solver which determine modes measured by monitor.",
     )
 
-    def plot(
-        self, x: float = None, y: float = None, z: float = None, ax: Ax = None, **kwargs
+    def plot(  # pylint:disable=too-many-arguments
+        self,
+        x: float = None,
+        y: float = None,
+        z: float = None,
+        ax: Ax = None,
+        sim_bounds: Bound = None,
+        **patch_kwargs
     ) -> Ax:
 
         # call the monitor.plot() function first
-        ax = super().plot(x=x, y=y, z=z, ax=ax, **kwargs)
+        ax = super().plot(x=x, y=y, z=z, ax=ax, **patch_kwargs)
 
-        kwargs_alpha = kwargs.get("alpha")
+        kwargs_alpha = patch_kwargs.get("alpha")
         arrow_alpha = ARROW_ALPHA if kwargs_alpha is None else kwargs_alpha
 
         # and then add an arrow using the direction comuputed from `_dir_arrow`.
@@ -198,6 +242,7 @@ class AbstractModeMonitor(PlanarMonitor, FreqMonitor):
             color=ARROW_COLOR_MONITOR,
             alpha=arrow_alpha,
             both_dirs=True,
+            sim_bounds=sim_bounds,
         )
         return ax
 
