@@ -2,7 +2,6 @@
 """ Container holding all information about simulation and its components"""
 from typing import Dict, Tuple, List, Set, Union
 from math import isclose
-from functools import wraps
 
 import pydantic
 import numpy as np
@@ -11,24 +10,29 @@ import matplotlib.pylab as plt
 import matplotlib as mpl
 from mpl_toolkits.axes_grid1 import make_axes_locatable
 
+from .base import cache
 from .validators import assert_unique_names, assert_objects_in_sim_bounds
 from .validators import validate_mode_objects_symmetry
 from .geometry import Box
-from .types import Symmetry, Ax, Shapely, FreqBound, Axis, GridSize
+from .types import Ax, Shapely, FreqBound, GridSize, Axis
 from .grid import Coords1D, Grid, Coords, GridSpec, UniformGrid
 from .medium import Medium, MediumType, AbstractMedium, PECMedium
+from .boundary import BoundarySpec, Symmetry, BlochBoundary, PECBoundary, PMCBoundary
+from .boundary import PML, StablePML, Absorber
 from .structure import Structure
 from .source import SourceType, PlaneWave, GaussianBeam, AstigmaticGaussianBeam
-from .monitor import MonitorType, Monitor, FreqMonitor
-from .pml import PMLTypes, PML, Absorber
+from .monitor import MonitorType, Monitor, FreqMonitor, AbstractFieldMonitor
 from .viz import add_ax_if_none, equal_aspect
+
 from .viz import MEDIUM_CMAP, PlotParams, plot_params_symmetry
 from .viz import plot_params_structure, plot_params_pml, plot_params_override_structures
+from .viz import plot_params_pec, plot_params_pmc, plot_params_bloch
 
 from ..version import __version__
 from ..constants import C_0, MICROMETER, SECOND, inf
 from ..log import log, Tidy3dKeyError, SetupError, ValidationError
 from ..static import make_static
+from ..updater import Updater
 
 # minimum number of grid points allowed per central wavelength in a medium
 MIN_GRIDS_PER_WVL = 6.0
@@ -43,29 +47,6 @@ MAX_CELLS_TIMES_STEPS = 1e17
 MAX_MONITOR_DATA_SIZE_BYTES = 10e9
 
 
-def cache(prop):
-    """Decorates a property to cache the previously computed values based on a hash of self."""
-
-    stored_values = {}
-
-    @wraps(prop)
-    def cached_property(self):
-        """The new property method to be returned by decorator."""
-
-        hash_key = hash(self)
-
-        # if the value has been computed before, we can simply return the stored value
-        if hash_key in stored_values:
-            return stored_values[hash_key]
-
-        # otherwise, we need to recompute the value, store it in the storage dict, and return
-        return_value = prop(self)
-        stored_values[hash_key] = return_value
-        return return_value
-
-    return cached_property
-
-
 class Simulation(Box):  # pylint:disable=too-many-public-methods
     """Contains all information about Tidy3d simulation.
 
@@ -75,6 +56,7 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
     >>> from tidy3d import UniformCurrentSource, GaussianPulse
     >>> from tidy3d import FieldMonitor, FluxMonitor
     >>> from tidy3d import GridSpec, AutoGrid
+    >>> from tidy3d import BoundarySpec, Boundary
     >>> sim = Simulation(
     ...     size=(2.0, 2.0, 2.0),
     ...     grid_spec=GridSpec(
@@ -105,10 +87,10 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
     ...         FluxMonitor(size=(1, 1, 0), center=(0, 0, 0), freqs=[2e14, 2.5e14], name='flux'),
     ...     ],
     ...     symmetry=(0, 0, 0),
-    ...     pml_layers=(
-    ...         PML(num_layers=20),
-    ...         PML(num_layers=30),
-    ...         None,
+    ...     boundary_spec=BoundarySpec(
+    ...         x = Boundary.pml(num_layers=20),
+    ...         y = Boundary.pml(num_layers=30),
+    ...         z = Boundary.periodic(),
     ...     ),
     ...     shutoff=1e-6,
     ...     courant=0.8,
@@ -142,7 +124,8 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         (0, 0, 0),
         title="Symmetries",
         description="Tuple of integers defining reflection symmetry across a plane "
-        "bisecting the simulation domain normal to the x-, y-, and z-axis, respectvely. "
+        "bisecting the simulation domain normal to the x-, y-, and z-axis "
+        "at the simulation center of each axis, respectvely. "
         "Each element can be ``0`` (no symmetry), ``1`` (even, i.e. 'PMC' symmetry) or "
         "``-1`` (odd, i.e. 'PEC' symmetry). "
         "Note that the vectorial nature of the fields must be taken into account to correctly "
@@ -163,6 +146,12 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         description="List of electric current sources injecting fields into the simulation.",
     )
 
+    boundary_spec: BoundarySpec = pydantic.Field(
+        BoundarySpec(),
+        title="Boundaries",
+        description="Specification of boundary conditions along each dimension.",
+    )
+
     monitors: List[MonitorType] = pydantic.Field(
         [],
         title="Monitors",
@@ -176,14 +165,6 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         description="Specifications for the simulation grid along each of the three directions.",
     )
 
-    pml_layers: Tuple[PMLTypes, PMLTypes, PMLTypes] = pydantic.Field(
-        (None, None, None),
-        title="Absorbing Layers",
-        description="Specifications for the absorbing layers on x, y, and z edges. "
-        "If ``None``, no absorber will be added on that dimension "
-        "and periodic boundary conditions will be used.",
-    )
-
     shutoff: pydantic.NonNegativeFloat = pydantic.Field(
         1e-5,
         title="Shutoff Condition",
@@ -260,11 +241,6 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
             _ = val.wavelength_from_sources(sources=values.get("sources"))
         return val
 
-    @pydantic.validator("pml_layers", always=True, allow_reuse=True)
-    def set_none_to_zero_layers(cls, val):
-        """if any PML layer is None, set it to an empty :class:`PML`."""
-        return tuple(PML(num_layers=0) if pml is None else pml for pml in val)
-
     _structures_in_bounds = assert_objects_in_sim_bounds("structures")
     _sources_in_bounds = assert_objects_in_sim_bounds("sources")
     _monitors_in_bounds = assert_objects_in_sim_bounds("monitors")
@@ -288,6 +264,19 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
     # _resolution_fine_enough = validate_resolution()
     # _plane_waves_in_homo = validate_plane_wave_intersections()
 
+    @pydantic.validator("boundary_spec", always=True)
+    def bloch_with_symmetry(cls, val, values):
+        """Error if a Bloch boundary is applied with symmetry"""
+        boundaries = val.to_list
+        symmetry = values.get("symmetry")
+        for dim, boundary in enumerate(boundaries):
+            num_bloch = sum(isinstance(bnd, BlochBoundary) for bnd in boundary)
+            if num_bloch > 0 and symmetry[dim] != 0:
+                raise SetupError(
+                    f"Bloch boundaries cannot be used with a symmetry along dimension {dim}."
+                )
+        return val
+
     @pydantic.validator("structures", always=True)
     def _validate_num_mediums(cls, val):
         """Error if too many mediums present."""
@@ -331,18 +320,17 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
 
         return val
 
-    @pydantic.validator("pml_layers", always=True)
+    @pydantic.validator("boundary_spec", always=True)
     def _structures_not_close_pml(cls, val, values):  # pylint:disable=too-many-locals
         """Warn if any structures lie at the simulation boundaries."""
 
-        if val is None:
-            return val
-
         sim_box = Box(size=values.get("size"), center=values.get("center"))
         sim_bound_min, sim_bound_max = sim_box.bounds
 
+        boundaries = val.to_list
         structures = values.get("structures")
         sources = values.get("sources")
+
         if (not structures) or (not sources):
             return val
 
@@ -361,25 +349,29 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
             for source in sources:
                 lambda0 = C_0 / source.source_time.freq0
 
-                zipped = zip(["x", "y", "z"], sim_bound_min, struct_bound_min, val)
-                for axis, sim_val, struct_val, pml in zipped:
+                zipped = zip(["x", "y", "z"], sim_bound_min, struct_bound_min, boundaries)
+                for axis, sim_val, struct_val, boundary in zipped:
+                    # The test is required only for PML and stable PML
+                    if not isinstance(boundary[0], (PML, StablePML)):
+                        continue
                     if (
-                        pml.num_layers > 0
+                        boundary[0].num_layers > 0
                         and struct_val > sim_val
-                        and not isinstance(pml, Absorber)
+                        and abs(sim_val - struct_val) < lambda0 / 2
                     ):
-                        if abs(sim_val - struct_val) < lambda0 / 2:
-                            warn(istruct, axis + "-min")
+                        warn(istruct, axis + "-min")
 
-                zipped = zip(["x", "y", "z"], sim_bound_max, struct_bound_max, val)
-                for axis, sim_val, struct_val, pml in zipped:
+                zipped = zip(["x", "y", "z"], sim_bound_max, struct_bound_max, boundaries)
+                for axis, sim_val, struct_val, boundary in zipped:
+                    # The test is required only for PML and stable PML
+                    if not isinstance(boundary[1], (PML, StablePML)):
+                        continue
                     if (
-                        pml.num_layers > 0
+                        boundary[1].num_layers > 0
                         and struct_val < sim_val
-                        and not isinstance(pml, Absorber)
+                        and abs(sim_val - struct_val) < lambda0 / 2
                     ):
-                        if abs(sim_val - struct_val) < lambda0 / 2:
-                            warn(istruct, axis + "-max")
+                        warn(istruct, axis + "-max")
 
         return val
 
@@ -435,8 +427,8 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
             log.warning("No sources in simulation.")
             return val
 
-        freq_min = min([freq_range[0] for freq_range in source_ranges], default=0.0)
-        freq_max = max([freq_range[1] for freq_range in source_ranges], default=0.0)
+        freq_min = min((freq_range[0] for freq_range in source_ranges), default=0.0)
+        freq_max = max((freq_range[1] for freq_range in source_ranges), default=0.0)
 
         for monitor_index, monitor in enumerate(val):
             if not isinstance(monitor, FreqMonitor):
@@ -576,7 +568,11 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         total_size_bytes = 0
         for monitor in self.monitors:
             monitor_inds = grid.discretize_inds(monitor, extend=True)
-            num_cells = np.prod([inds[1] - inds[0] for inds in monitor_inds])
+            num_cells = [inds[1] - inds[0] for inds in monitor_inds]
+            # take monitor downsampling into account
+            if isinstance(monitor, AbstractFieldMonitor):
+                num_cells = monitor.downsampled_num_cells(num_cells)
+            num_cells = np.prod(num_cells)
             monitor_size = monitor.storage_size(num_cells=num_cells, tmesh=tmesh)
 
             total_size_bytes += monitor_size
@@ -683,6 +679,7 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         ax = self.plot_symmetries(ax=ax, x=x, y=y, z=z)
         ax = self.plot_pml(ax=ax, x=x, y=y, z=z)
         ax = self._set_plot_bounds(ax=ax, x=x, y=y, z=z)
+        ax = self.plot_boundaries(ax=ax, x=x, y=y, z=z)
         return ax
 
     @equal_aspect
@@ -735,6 +732,7 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         ax = self.plot_symmetries(ax=ax, x=x, y=y, z=z)
         ax = self.plot_pml(ax=ax, x=x, y=y, z=z)
         ax = self._set_plot_bounds(ax=ax, x=x, y=y, z=z)
+        ax = self.plot_boundaries(ax=ax, x=x, y=y, z=z)
         return ax
 
     @equal_aspect
@@ -861,9 +859,15 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         """
 
         structures = self.structures
-        alpha_used = alpha is not None and 0 < alpha < 1
 
-        if alpha_used:
+        # alpha is None just means plot without any transparency
+        if alpha is None:
+            alpha = 1
+
+        if alpha <= 0:
+            return ax
+
+        if alpha < 1:
             medium_shapes = self._filter_structures_plane(structures=structures, x=x, y=y, z=z)
         else:
             structures = [self.background_structure] + structures
@@ -871,7 +875,7 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
 
         eps_min, eps_max = self.eps_bounds(freq=freq)
         for (medium, shape) in medium_shapes:
-            if medium == self.medium and alpha_used:
+            if medium == self.medium and alpha < 1:
                 continue
             ax = self._plot_shape_structure_eps(
                 freq=freq,
@@ -984,8 +988,9 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         matplotlib.axes._subplots.Axes
             The supplied or created matplotlib axes.
         """
+        bounds = self.bounds
         for source in self.sources:
-            ax = source.plot(x=x, y=y, z=z, alpha=alpha, ax=ax)
+            ax = source.plot(x=x, y=y, z=z, alpha=alpha, ax=ax, sim_bounds=bounds)
         ax = self._set_plot_bounds(ax=ax, x=x, y=y, z=z)
         return ax
 
@@ -1014,8 +1019,9 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         matplotlib.axes._subplots.Axes
             The supplied or created matplotlib axes.
         """
+        bounds = self.bounds
         for monitor in self.monitors:
-            ax = monitor.plot(x=x, y=y, z=z, alpha=alpha, ax=ax)
+            ax = monitor.plot(x=x, y=y, z=z, alpha=alpha, ax=ax, sim_bounds=bounds)
         ax = self._set_plot_bounds(ax=ax, x=x, y=y, z=z)
         return ax
 
@@ -1028,8 +1034,14 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         List[Tuple[float, float]]
             List containing the number of absorber layers in - and + boundaries.
         """
+        num_layers = [[0, 0], [0, 0], [0, 0]]
 
-        return [(pml.num_layers, pml.num_layers) for pml in self.pml_layers]
+        for idx_i, boundary1d in enumerate(self.boundary_spec.to_list):
+            for idx_j, boundary in enumerate(boundary1d):
+                if isinstance(boundary, (PML, StablePML, Absorber)):
+                    num_layers[idx_i][idx_j] = boundary.num_layers
+
+        return num_layers
 
     @property
     def pml_thicknesses(self) -> List[Tuple[float, float]]:
@@ -1097,10 +1109,12 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         """make a list of Box objects representing the pml to plot on plane."""
         pml_boxes = []
         pml_thicks = self.pml_thicknesses
-        for pml_axis, pml_layer in enumerate(self.pml_layers):
-            if pml_layer is None or pml_layer.num_layers == 0 or pml_axis == normal_axis:
+        for pml_axis, num_layers_dim in enumerate(self.num_pml_layers):
+            if pml_axis == normal_axis:
                 continue
-            for sign, pml_height in zip((-1, 1), pml_thicks[pml_axis]):
+            for sign, pml_height, num_layers in zip((-1, 1), pml_thicks[pml_axis], num_layers_dim):
+                if num_layers == 0:
+                    continue
                 pml_box = self._make_pml_box(pml_axis=pml_axis, pml_height=pml_height, sign=sign)
                 pml_boxes.append(pml_box)
         return pml_boxes
@@ -1159,8 +1173,11 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
             plot_params.edgecolor = "lightsteelblue"
             plot_params.hatch = "++"
         elif sym_value == -1:
-            plot_params.facecolor = "rosybrown"
-            plot_params.edgecolor = "rosybrown"
+            # plot_params.facecolor = "rosybrown"
+            # plot_params.edgecolor = "rosybrown"
+            # plot_params.hatch = "--"
+            plot_params.facecolor = "goldenrod"
+            plot_params.edgecolor = "goldenrod"
             plot_params.hatch = "--"
 
         return plot_params
@@ -1246,6 +1263,130 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
 
         return ax
 
+    @equal_aspect
+    @add_ax_if_none
+    def plot_boundaries(  # pylint:disable=too-many-locals
+        self,
+        x: float = None,
+        y: float = None,
+        z: float = None,
+        ax: Ax = None,
+        **kwargs,
+    ) -> Ax:
+        """Plot the simulation boundary conditions as lines on a plane
+           defined by one nonzero x,y,z coordinate.
+
+        Parameters
+        ----------
+        x : float = None
+            position of plane in x direction, only one of x, y, z must be specified to define plane.
+        y : float = None
+            position of plane in y direction, only one of x, y, z must be specified to define plane.
+        z : float = None
+            position of plane in z direction, only one of x, y, z must be specified to define plane.
+        ax : matplotlib.axes._subplots.Axes = None
+            Matplotlib axes to plot on, if not specified, one is created.
+        **kwargs
+            Optional keyword arguments passed to the matplotlib ``LineCollection``.
+            For details on accepted values, refer to
+            `Matplotlib's documentation <https://tinyurl.com/2p97z4cn>`_.
+
+        Returns
+        -------
+        matplotlib.axes._subplots.Axes
+            The supplied or created matplotlib axes.
+        """
+
+        kwargs.setdefault("clip_on", False)
+
+        def set_plot_params(boundary_edge, lim, side, thickness):
+            """Return the line plot properties such as color and opacity based on the boundary"""
+            if isinstance(boundary_edge, PECBoundary):
+                plot_params = plot_params_pec.copy(deep=True)
+            elif isinstance(boundary_edge, PMCBoundary):
+                plot_params = plot_params_pmc.copy(deep=True)
+            elif isinstance(boundary_edge, BlochBoundary):
+                plot_params = plot_params_bloch.copy(deep=True)
+            else:
+                plot_params = PlotParams()
+                plot_params.alpha = 0
+
+            # expand axis limit so that the axis ticks and labels aren't covered
+            new_lim = lim
+            if plot_params.alpha != 0:
+                if side == -1:
+                    new_lim = lim - thickness
+                elif side == 1:
+                    new_lim = lim + thickness
+
+            return plot_params, new_lim
+
+        boundaries = self.boundary_spec.to_list
+
+        normal_axis, _ = self.parse_xyz_kwargs(x=x, y=y, z=z)
+        _, (dim_u, dim_v) = self.pop_axis([0, 1, 2], axis=normal_axis)
+
+        umin, umax = ax.get_xlim()
+        vmin, vmax = ax.get_ylim()
+
+        size_factor = 1.0 / 35.0
+        thickness_u = (umax - umin) * size_factor
+        thickness_v = (vmax - vmin) * size_factor
+
+        # boundary along the u axis, minus side
+        plot_params, ulim_minus = set_plot_params(boundaries[dim_u][0], umin, -1, thickness_u)
+        rect = mpl.patches.Rectangle(
+            xy=(umin - thickness_u, vmin),
+            width=thickness_u,
+            height=(vmax - vmin),
+            zorder=np.inf,
+            **plot_params.to_kwargs(),
+            **kwargs,
+        )
+        ax.add_patch(rect)
+
+        # boundary along the u axis, plus side
+        plot_params, ulim_plus = set_plot_params(boundaries[dim_u][1], umax, 1, thickness_u)
+        rect = mpl.patches.Rectangle(
+            xy=(umax, vmin),
+            width=thickness_u,
+            height=(vmax - vmin),
+            zorder=np.inf,
+            **plot_params.to_kwargs(),
+            **kwargs,
+        )
+        ax.add_patch(rect)
+
+        # boundary along the v axis, minus side
+        plot_params, vlim_minus = set_plot_params(boundaries[dim_v][0], vmin, -1, thickness_v)
+        rect = mpl.patches.Rectangle(
+            xy=(umin, vmin - thickness_v),
+            width=(umax - umin),
+            height=thickness_v,
+            zorder=np.inf,
+            **plot_params.to_kwargs(),
+            **kwargs,
+        )
+        ax.add_patch(rect)
+
+        # boundary along the v axis, plus side
+        plot_params, vlim_plus = set_plot_params(boundaries[dim_v][1], vmax, 1, thickness_v)
+        rect = mpl.patches.Rectangle(
+            xy=(umin, vmax),
+            width=(umax - umin),
+            height=thickness_v,
+            zorder=np.inf,
+            **plot_params.to_kwargs(),
+            **kwargs,
+        )
+        ax.add_patch(rect)
+
+        # ax = self._set_plot_bounds(ax=ax, x=x, y=y, z=z)
+        ax.set_xlim([ulim_minus, ulim_plus])
+        ax.set_ylim([vlim_minus, vlim_plus])
+
+        return ax
+
     def _set_plot_bounds(self, ax: Ax, x: float = None, y: float = None, z: float = None) -> Ax:
         """Sets the xy limits of the simulation at a plane, useful after plotting.
 
@@ -1392,8 +1533,9 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
             Minumum and maximum frequencies of the power spectrum of the sources.
         """
         source_ranges = [source.source_time.frequency_range() for source in self.sources]
-        freq_min = min([freq_range[0] for freq_range in source_ranges], default=0.0)
-        freq_max = max([freq_range[1] for freq_range in source_ranges], default=0.0)
+        freq_min = min((freq_range[0] for freq_range in source_ranges), default=0.0)
+        freq_max = max((freq_range[1] for freq_range in source_ranges), default=0.0)
+
         return (freq_min, freq_max)
 
     """ Discretization """
@@ -1408,7 +1550,7 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
             Time step (seconds).
         """
         dl_mins = [np.min(sizes) for sizes in self.grid.sizes.to_list]
-        dl_sum_inv_sq = sum([1 / dl**2 for dl in dl_mins])
+        dl_sum_inv_sq = sum((1 / dl**2 for dl in dl_mins))
         dl_avg = 1 / np.sqrt(dl_sum_inv_sq)
         return self.courant * dl_avg / C_0
 
@@ -1552,7 +1694,6 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         self, box: Box, coord_key: str = "centers", freq: float = None
     ) -> Dict[str, xr.DataArray]:
         """Get array of permittivity at volume specified by box and freq
-
         Parameters
         ----------
         box : :class:`Box`
@@ -1567,7 +1708,6 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         freq : float = None
             The frequency to evaluate the mediums at.
             If not specified, evaluates at infinite frequency.
-
         Returns
         -------
         xarray.DataArray
@@ -1608,3 +1748,28 @@ class Simulation(Box):  # pylint:disable=too-many-public-methods
         # combine all data into dictionary
         coords = sub_grid[coord_key]
         return make_eps_data(coords)
+
+    @classmethod
+    def from_file(cls, fname: str, **parse_kwargs):
+        """Loads a :class:`Tidy3dBaseModel` from .yaml or .json file.
+
+        Parameters
+        ----------
+        fname : str
+            Full path to the .yaml or .json file to load the :class:`Tidy3dBaseModel` from.
+        **parse_kwargs
+            Keyword arguments passed to either pydantic's ``parse_file`` or ``parse_raw`` methods
+            for ``.json`` and ``.yaml`` file formats, respectively.
+        Returns
+        -------
+        :class:`Tidy3dBaseModel`
+            An instance of the component class calling `load`.
+
+        Example
+        -------
+        >>> simulation = Simulation.from_file(fname='folder/sim.json') # doctest: +SKIP
+        """
+
+        updater = Updater.from_file(fname)
+        sim_dict = updater.update_to_current()
+        return Simulation.parse_obj(sim_dict, **parse_kwargs)
