@@ -9,7 +9,7 @@ import pydantic
 import numpy as np
 
 from .base import Tidy3dBaseModel
-from .types import Direction, Polarization, Ax, FreqBound, Array, Axis, ArrayLike
+from .types import Direction, Polarization, Ax, FreqBound, Array, Axis, ArrayLike, Bound
 from .validators import assert_plane, validate_name_str
 from .geometry import Box
 from .mode import ModeSpec
@@ -49,7 +49,9 @@ class SourceTime(ABC, Tidy3dBaseModel):
             Complex-valued source amplitude at that time..
         """
 
-    def spectrum(self, times: Array[float], freqs: Array[float], dt: float) -> complex:
+    def spectrum(
+        self, times: Array[float], freqs: Array[float], dt: float, complex_fields: bool = False
+    ) -> complex:
         """Complex-valued source spectrum as a function of frequency
 
         Parameters
@@ -62,6 +64,8 @@ class SourceTime(ABC, Tidy3dBaseModel):
         dt : float or np.ndarray
             Time step to weight FT integral with.
             If array, use to weigh each of the time intervals in ``times``.
+        complex_fields : bool
+            Whether time domain fields are complex, e.g., for Bloch boundaries
 
         Returns
         -------
@@ -69,7 +73,10 @@ class SourceTime(ABC, Tidy3dBaseModel):
             Complex-valued array (of len(freqs)) containing spectrum at those frequencies.
         """
 
-        time_amps = np.real(self.amp_time(times))
+        if complex_fields:
+            time_amps = self.amp_time(times)
+        else:
+            time_amps = np.real(self.amp_time(times))
 
         # Cut to only relevant times
         count_times = np.where(np.abs(time_amps) / np.amax(np.abs(time_amps)) > DFT_CUTOFF)
@@ -111,7 +118,9 @@ class SourceTime(ABC, Tidy3dBaseModel):
         return ax
 
     @add_ax_if_none
-    def plot_spectrum(self, times: Array[float], num_freqs: int = 101, ax: Ax = None) -> Ax:
+    def plot_spectrum(
+        self, times: Array[float], num_freqs: int = 101, ax: Ax = None, complex_fields: bool = False
+    ) -> Ax:
         """Plot the complex-valued amplitude of the source time-dependence.
 
         Parameters
@@ -125,6 +134,8 @@ class SourceTime(ABC, Tidy3dBaseModel):
             Number of frequencies to plot within the SourceTime.frequency_range.
         ax : matplotlib.axes._subplots.Axes = None
             Matplotlib axes to plot on, if not specified, one is created.
+        complex_fields : bool
+            Whether time domain fields are complex, e.g., for Bloch boundaries
 
         Returns
         -------
@@ -142,7 +153,7 @@ class SourceTime(ABC, Tidy3dBaseModel):
         fmin, fmax = self.frequency_range()
         freqs = np.linspace(fmin, fmax, num_freqs)
 
-        spectrum = self.spectrum(times=times, dt=dt, freqs=freqs)
+        spectrum = self.spectrum(times=times, dt=dt, freqs=freqs, complex_fields=complex_fields)
 
         ax.plot(freqs, spectrum.real, color="blueviolet", label="real")
         ax.plot(freqs, spectrum.imag, color="crimson", label="imag")
@@ -283,14 +294,20 @@ class Source(Box, ABC):
         """Returns a vector indicating the source polarization for arrow plotting, if not None."""
         return None
 
-    def plot(
-        self, x: float = None, y: float = None, z: float = None, ax: Ax = None, **kwargs
+    def plot(  #  pylint:disable=too-many-arguments
+        self,
+        x: float = None,
+        y: float = None,
+        z: float = None,
+        ax: Ax = None,
+        sim_bounds: Bound = None,
+        **patch_kwargs
     ) -> Ax:
 
         # call the `Source.plot()` function first.
-        ax = super().plot(x=x, y=y, z=z, ax=ax, **kwargs)
+        ax = super().plot(x=x, y=y, z=z, ax=ax, **patch_kwargs)
 
-        kwargs_alpha = kwargs.get("alpha")
+        kwargs_alpha = patch_kwargs.get("alpha")
         arrow_alpha = ARROW_ALPHA if kwargs_alpha is None else kwargs_alpha
 
         # then add the arrow based on the propagation direction
@@ -305,6 +322,7 @@ class Source(Box, ABC):
                 color=ARROW_COLOR_SOURCE,
                 alpha=arrow_alpha,
                 both_dirs=False,
+                sim_bounds=sim_bounds,
             )
 
         if self._pol_vector is not None:
@@ -318,6 +336,7 @@ class Source(Box, ABC):
                 color=ARROW_COLOR_POLARIZATION,
                 alpha=arrow_alpha,
                 both_dirs=False,
+                sim_bounds=sim_bounds,
             )
 
         return ax
@@ -500,10 +519,12 @@ class AngledFieldSource(DirectionalSource, ABC):
         normal_dir = [0.0, 0.0, 0.0]
         normal_dir[self.injection_axis] = 1.0
         propagation_dir = list(self._dir_vector)
-        pol_vector = np.cross(normal_dir, propagation_dir)
-        if np.all(pol_vector == 0.0):
-            pol_vector = np.array((0, 1, 0)) if self.injection_axis == 0 else np.array((1, 0, 0))
-        return self.rotate_points(pol_vector, propagation_dir, angle=self.pol_angle)
+        pol_vector_s = np.cross(normal_dir, propagation_dir)
+        if np.all(pol_vector_s == 0.0):
+            pol_vector_s = np.array((0, 1, 0)) if self.injection_axis == 0 else np.array((1, 0, 0))
+        pol_vector_p = np.cross(propagation_dir, pol_vector_s)
+        pol_vector_p = np.array(pol_vector_p) / np.linalg.norm(pol_vector_p)
+        return self.rotate_points(pol_vector_p, propagation_dir, angle=self.pol_angle)
 
 
 class ModeSource(DirectionalSource, PlanarSource):
@@ -568,15 +589,15 @@ class PlaneWave(AngledFieldSource, PlanarSource):
     >>> pw_source = PlaneWave(size=(inf,0,inf), source_time=pulse, pol_angle=0.1, direction='+')
     """
 
-    @pydantic.validator("angle_theta", always=True)
-    def normal_incidence(cls, val):
-        """Raise not implemented error if not normal incidence."""
-        if val > 0.0:
-            raise NotImplementedError(
-                "Plane wave with off-normal incidence requires Bloch "
-                "boundary conditions, which are not yet implemented."
-            )
-        return val
+    # @pydantic.validator("angle_theta", always=True)
+    # def normal_incidence(cls, val):
+    #     """Raise not implemented error if not normal incidence."""
+    #     if val > 0.0:
+    #         raise NotImplementedError(
+    #             "Plane wave with off-normal incidence requires Bloch "
+    #             "boundary conditions, which are not yet implemented."
+    #         )
+    #     return val
 
 
 class GaussianBeam(AngledFieldSource, PlanarSource):
