@@ -1,10 +1,9 @@
 # pylint:disable=unused-argument
 """ Defines various validation functions that get used to ensure inputs are legit """
-
 import pydantic
 
-from ..log import ValidationError, SetupError
 from .geometry import Box
+from ..log import ValidationError, SetupError
 
 """ Explanation of pydantic validators:
 
@@ -44,6 +43,7 @@ def assert_plane():
 
     @pydantic.validator("size", allow_reuse=True, always=True)
     def is_plane(cls, val):
+        """Raise validation error if not planar."""
         if val.count(0.0) != 1:
             raise ValidationError(f"'{cls.__name__}' object must be planar, given size={val}")
         return val
@@ -122,7 +122,8 @@ def assert_objects_in_sim_bounds(field_name: str):
     def objects_in_sim_bounds(cls, val, values):
         """check for intersection of each structure with simulation bounds."""
         sim_center = values.get("center")
-        sim_box = Box(size=values.get("size"), center=sim_center)
+        sim_size = values.get("size")
+        sim_box = Box(size=sim_size, center=sim_center)
 
         for position_index, geometric_object in enumerate(val):
             if not sim_box.intersects(geometric_object.geometry):
