@@ -21,7 +21,7 @@ ARROW_ALPHA = 0.8
 
 
 # this times the min of axis height and width gives the arrow length
-ARROW_LENGTH_FACTOR = 0.4
+ARROW_LENGTH_FACTOR = 0.1
 
 # this times ARROW_LENGTH gives width
 ARROW_WIDTH_FACTOR = 0.4
@@ -88,7 +88,7 @@ class PlotParams(Tidy3dBaseModel):
         """Update the plot params with supplied kwargs."""
         new_plot_params = self.copy(deep=True)
         for key, value in kwargs.items():
-            if key not in ("type",) and value is not None:
+            if key not in ("type",) and value is not None and key in self.__fields__:
                 setattr(new_plot_params, key, value)
         return new_plot_params
 
@@ -106,6 +106,9 @@ plot_params_structure = PlotParams()
 plot_params_source = PlotParams(alpha=0.4, facecolor="limegreen", edgecolor="limegreen", lw=3)
 plot_params_monitor = PlotParams(alpha=0.4, facecolor="orange", edgecolor="orange", lw=3)
 plot_params_pml = PlotParams(alpha=0.7, facecolor="gray", edgecolor="gray", hatch="x")
+plot_params_pec = PlotParams(alpha=1.0, facecolor="gold", edgecolor="black")
+plot_params_pmc = PlotParams(alpha=1.0, facecolor="lightsteelblue", edgecolor="black")
+plot_params_bloch = PlotParams(alpha=1.0, facecolor="orchid", edgecolor="black")
 plot_params_symmetry = PlotParams(edgecolor="gray", facecolor="gray", alpha=0.6)
 plot_params_override_structures = PlotParams(linewidth=0.4, edgecolor="black", fill=False)
 
