@@ -3,8 +3,9 @@
 from typing import Tuple, List
 from enum import Enum
 import requests
-from pydantic import BaseModel, PositiveInt, NonNegativeFloat, PositiveFloat, Field
+from pydantic import PositiveInt, NonNegativeFloat, PositiveFloat, Field
 
+from ...components.base import Tidy3dBaseModel
 from ...components.types import Literal
 from ...components import PoleResidue
 from ...constants import MICROMETER, HERTZ
@@ -16,23 +17,23 @@ from .fit import DispersionFitter
 BOUND_MAX_FACTOR = 10
 
 
-class AdvancedFitterParam(BaseModel):
+class AdvancedFitterParam(Tidy3dBaseModel):
     """Advanced fitter parameters"""
 
     bound_amp: NonNegativeFloat = Field(
         None,
         title="Upper bound of oscillator strength",
-        description="Upper bound of oscillator strength in the model "
-        "(The default 'None' will trigger automatic setup based on the "
-        "frequency range of interest).",
-        unis=HERTZ,
+        description="Upper bound of real and imagniary part of oscillator "
+        "strength ``c`` in the model :class:`.PoleResidue` (The default 'None' will trigger "
+        "automatic setup based on the frequency range of interest).",
+        units=HERTZ,
     )
     bound_f: NonNegativeFloat = Field(
         None,
         title="Upper bound of pole frequency",
-        description="Upper bound of pole frequency in the model "
-        "(The default 'None' will trigger automatic setup based on the "
-        "frequency range of interest).",
+        description="Upper bound of real and imaginary part of pole "
+        "frequency ``a`` in the model :class:`.PoleResidue` (The default 'None' will trigger "
+        "automatic setup based on the frequency range of interest).",
         units=HERTZ,
     )
     bound_eps_inf: float = Field(
@@ -59,7 +60,7 @@ class AdvancedFitterParam(BaseModel):
 
 # FitterData will be used internally
 class FitterData(AdvancedFitterParam):
-    """Data class for request body of Fitter where dipsersion data is input through list"""
+    """Data class for request body of Fitter where dipsersion data is input through list."""
 
     wvl_um: List[float] = Field(
         ...,
@@ -95,7 +96,7 @@ class FitterData(AdvancedFitterParam):
         100.0,
         title="Upper bound of oscillator strength",
         description="Upper bound of oscillator strength in the model.",
-        unis="eV",
+        units="eV",
     )
     bound_f: PositiveFloat = Field(
         100.0,
@@ -173,36 +174,33 @@ class StableDispersionFitter(DispersionFitter):
 
         return headers
 
-    def fit(  # pylint:disable=arguments-differ, too-many-locals
+    def _setup_webdata(
         self,
-        num_poles: PositiveInt = 1,
-        num_tries: PositiveInt = 50,
-        tolerance_rms: NonNegativeFloat = 1e-2,
-        advanced_param: AdvancedFitterParam = AdvancedFitterParam(),
-    ) -> Tuple[PoleResidue, float]:
-        """Fits data a number of times and returns best results.
+        num_poles: PositiveInt,
+        num_tries: PositiveInt,
+        tolerance_rms: NonNegativeFloat,
+        advanced_param: AdvancedFitterParam,
+    ) -> FitterData:
+        """Setup FitterData to be provided to webservice
 
         Parameters
         ----------
-        num_poles : PositiveInt, optional
+        num_poles : PositiveInt
             Number of poles in the model.
-        num_tries : PositiveInt, optional
+        num_tries : PositiveInt
             Number of optimizations to run with random initial guess.
-        tolerance_rms : NonNegativeFloat, optional
+        tolerance_rms : NonNegativeFloat
             RMS error below which the fit is successful and the result is returned.
-        advanced_param : :class:`AdvancedFitterParam`, optional
+        advanced_param : :class:`AdvancedFitterParam`
             Other advanced parameters.
 
         Returns
         -------
-        Tuple[:class:``PoleResidue``, float]
-            Best results of multiple fits: (dispersive medium, RMS error).
+        :class:`FitterData`
+            Data class for request body of Fitter where dipsersion
+            data is input through list.
         """
 
-        # get url
-        url_server = self._set_url("default")
-        headers = self._setup_server(url_server)
-
         # set up bound_f, bound_amp
         if advanced_param.bound_f is None:
             advanced_param.bound_f = self.frequency_range[1] * BOUND_MAX_FACTOR
@@ -227,6 +225,41 @@ class StableDispersionFitter(DispersionFitter):
             nlopt_maxeval=advanced_param.nlopt_maxeval,
         )
 
+        return web_data
+
+    def fit(  # pylint:disable=arguments-differ, too-many-locals
+        self,
+        num_poles: PositiveInt = 1,
+        num_tries: PositiveInt = 50,
+        tolerance_rms: NonNegativeFloat = 1e-2,
+        advanced_param: AdvancedFitterParam = AdvancedFitterParam(),
+    ) -> Tuple[PoleResidue, float]:
+        """Fits data a number of times and returns best results.
+
+        Parameters
+        ----------
+        num_poles : PositiveInt, optional
+            Number of poles in the model.
+        num_tries : PositiveInt, optional
+            Number of optimizations to run with random initial guess.
+        tolerance_rms : NonNegativeFloat, optional
+            RMS error below which the fit is successful and the result is returned.
+        advanced_param : :class:`AdvancedFitterParam`, optional
+            Other advanced parameters.
+
+        Returns
+        -------
+        Tuple[:class:`.PoleResidue`, float]
+            Best results of multiple fits: (dispersive medium, RMS error).
+        """
+
+        # get url
+        url_server = self._set_url("default")
+        headers = self._setup_server(url_server)
+
+        # setup web_data
+        web_data = self._setup_webdata(num_poles, num_tries, tolerance_rms, advanced_param)
+
         resp = requests.post(
             url_server + "/dispersion/fit",
             headers=headers,
